# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-Warnings
Version:	0.038
Release:	1.%{__distinit}%{__distvers}
Summary:	Test for warnings and the lack of them
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Warnings
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Warnings-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(parent)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(if)
BuildRequires:	perl(lib)
BuildRequires:	perl(Term::ANSIColor)
BuildRequires:	perl(Test::More) >= 0.94
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Check) >= 0.011
BuildRequires:	perl(CPAN::Meta::Prereqs)
BuildRequires:	perl(CPAN::Meta::Requirements)
BuildRequires:	perl(PadWalker)
BuildRequires:	perl(Test::Tester) >= 0.108
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)

%description
If you've ever tried to use Test::NoWarnings to confirm there are no warnings
generated by your tests, combined with the convenience of done_testing to not
have to declare a test count, you'll have discovered that these two features do
not play well together, as the test count will be calculated before the
warnings test is run, resulting in a TAP error (see examples/test_nowarnings.pl
in this distribution for a demonstration).

This module is intended to be used as a drop-in replacement for
Test::NoWarnings: it also adds an extra test, but runs this test before
done_testing calculates the test count, rather than after. It does this by
hooking into done_testing as well as via an END block. You can declare a plan,
or not, and things will still Just Work.

It is actually equivalent to:

    use Test::NoWarnings 1.04 ':early';

as warnings are still printed normally as they occur. You are safe, and
enthusiastically encouraged, to perform a global search-replace of the above
with use Test::Warnings; whether or not your tests have a plan.

%prep
%setup -q -n Test-Warnings-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENCE
%doc Changes CONTRIBUTING README examples/
%{perl_vendorlib}/Test/
%{perl_vendorlib}/Test2/
%{_mandir}/man3/Test::Warnings.3*
%{_mandir}/man3/Test2::Warnings.3*

%changelog
* Sun Feb  2 2025 Paul Howarth <paul@city-fan.org> - 0.038-1
- Update to 0.038
  - Refrain from swapping out done_testing method if :no_end_test is configured

* Mon Jan  6 2025 Paul Howarth <paul@city-fan.org> - 0.037-1
- Update to 0.037
  - Remove unneeded use of Import::Into
  - Fix for tests that invoke Test::Warnings->import directly

* Sun Jan  5 2025 Paul Howarth <paul@city-fan.org> - 0.036-1
- Update to 0.036
  - Allow tests to pass even when Import::Into is not installed (CPAN RT#158296)
  - Add backcompat shim for cases where Test::More is loaded in tests after
    Test::Warnings
  - Avoid redefinition warnings when $^W is enabled in tests (CPAN RT#158297)

* Fri Jan  3 2025 Paul Howarth <paul@city-fan.org> - 0.034-1
- Update to 0.034
  - Fix Test2 compatibility for done_testing()
  - Test2::Warnings added as a simple wrapper (for now)

* Tue Jan 23 2024 Paul Howarth <paul@city-fan.org> - 0.033-1
- Update to 0.033
  - Add Test2 compatibility in the test triggered by done_testing()
  - New long-awaited feature (!!!) "allow_patterns", to either
    temporarily or globally exempt particular warning patterns

* Sun Oct  1 2023 Paul Howarth <paul@city-fan.org> - 0.032-1
- Update to 0.032
  - New config variable, $ENV{PERL_TEST_WARNINGS_ONLY_REPORT_WARNINGS}, for
    temporarily turning failures into reports

* Wed May 17 2023 Paul Howarth <paul@city-fan.org> - 0.031-6
- Use SPDX-format license tag

* Wed Jul 14 2021 Paul Howarth <paul@city-fan.org> - 0.031-1
- Update to 0.031
  - Remove unneeded developer prereqs that caused metacpan to unduly raise the
    river position of some dependent modules
- Use %%license unconditionally
- Fix dist tags for Alma and Rocky Linux

* Sun Mar 22 2020 Paul Howarth <paul@city-fan.org> - 0.030-1
- Update to 0.030
  - Fix tests that can fail when there is already an installed module named
    Foo::Bar::Baz (CPAN RT#132140)

* Sat Mar 14 2020 Paul Howarth <paul@city-fan.org> - 0.029-1
- Update to 0.029
  - New :report_warnings feature, for printing all of the (unexpected) warning
    content when had_no_warnings() is called (GH#10)

* Sun Dec 22 2019 Paul Howarth <paul@city-fan.org> - 0.028-1
- Update to 0.028
  - Allow for warnings->import being called after importing the "warnings" sub

* Sat Sep 28 2019 Paul Howarth <paul@city-fan.org> - 0.027-1
- Update to 0.027
  - New :fail_on_warning feature, for more easily seeing where the surprising
    warning appeared during testing

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 0.026-11
- Perl 5.30 rebuild

* Wed Apr  4 2018 Paul Howarth <paul@city-fan.org> - 0.026-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 0.026-4
- Support distributions as old as Fedora 9 since we have Test::More ≥ 0.88
  there now

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 0.026-3
- BR: perl-generators where possible
- Simplify find command using -delete

* Wed Jan 27 2016 Paul Howarth <paul@city-fan.org> - 0.026-1
- Update to 0.026
  - Fixed use of modules loaded by t/zzz-check-breaks.t
  - Fix stderr suppression on perl 5.6

* Mon Jan 25 2016 Paul Howarth <paul@city-fan.org> - 0.025-1
- Update to 0.025
  - Prereqs lowered from required to suggested:
    - CPAN::Meta::Check
    - CPAN::Meta::Requirements
  - Tests are now quieter to avoid causing confusion, by suppressing the
    printing of stderr in tests

* Sun Dec 27 2015 Paul Howarth <paul@city-fan.org> - 0.024-1
- Update to 0.024
  - Remove diagnostics accidentally left in new test

* Tue Dec 22 2015 Paul Howarth <paul@city-fan.org> - 0.023-1
- Update to 0.023
  - Properly handle propagating warnings to previously declared handlers that
    are not coderefs (i.e. a sub name, or the magic DEFAULT and IGNORE)

* Mon Dec 21 2015 Paul Howarth <paul@city-fan.org> - 0.022-1
- Update to 0.022
  - Propagate all warnings to any previously-declared __WARN__ handlers
    (unlike with __DIE__, merely calling warn() is not sufficient)

* Thu Jun 25 2015 Paul Howarth <paul@city-fan.org> - 0.021-3
- Perl 5.22 rebuild

* Mon Mar 23 2015 Paul Howarth <paul@city-fan.org> - 0.021-1
- Update to 0.021
  - Add a x_breaks entry for conflicting versions of File::pushd that
    inadvertently call our exported warnings() rather than invoking
    warnings.pm, and documented this undesired interaction

* Wed Jan  7 2015 Paul Howarth <paul@city-fan.org> - 0.020-1
- Update to 0.020
  - Re-release to fix problematic $VERSION declaration (CPAN RT#101239)

* Fri Dec 19 2014 Paul Howarth <paul@city-fan.org> - 0.019-1
- Update to 0.019
  - Fix test to allow for special characters (e.g. MSWin32 file separators) in
    filenames (PR#7)

* Thu Dec 18 2014 Paul Howarth <paul@city-fan.org> - 0.018-1
- Update to 0.018
  - Fix test to not depend on message formatting changes in newer Carp

* Wed Dec 17 2014 Paul Howarth <paul@city-fan.org> - 0.017-1
- Update to 0.017
  - Handle other warning handlers passing us partial warning messages by
    re-adding the source file and line number
- Add patch to fix compatibility with Carp < 1.25 (GH#6)

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.016-2
- Use %%license where possible

* Sun Jun 22 2014 Paul Howarth <paul@city-fan.org> - 0.016-1
- Update to 0.16
  - Fix prereq problem with last release - now no longer testing the example
    scripts for user installs

* Fri Jun 20 2014 Paul Howarth <paul@city-fan.org> - 0.015-1
- Update to 0.15
  - Adjusted packaging and tests to become perl-5.6 friendly, including only
    using core or dual-lifed prerequisites
- Switch to ExtUtils::MakeMaker flow

* Mon Mar  3 2014 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Fix test that fails when FOO or BAR environment variables are set
    (CPAN RT#93447)

* Mon Dec 16 2013 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013
  - Update configure_requires checking in Makefile.PL

* Mon Oct 14 2013 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012
  - Re-release to fix t/00-report-prereqs.t use of CPAN::Meta::Requirements

* Sun Oct 13 2013 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011
  - Unnecessary tests removed
  - CONTRIBUTING file added
- Drop buildreqs only needed for removed tests
- BR: optional test requirement perl(CPAN::Meta::Requirements)

* Wed Sep 25 2013 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Re-release with fixed compile test
- Update dependencies
- Package examples

* Wed Sep 11 2013 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - Fixed error in synopsis (we do not export anything by default)
  - A caveat added to the documentation regarding embedding warning checks
    inside another sub
  - ':no_end_test' now also covers side effects of done_testing, as well as
    END blocks, making it possible to use the warning(s) subs without having an
    end warning test while using done_testing (necessary when combining with
    the 'if' pragma)
  - END tests will not be added by a subequent use of Test::Warnings if a
    previous one passed ':no_end_test'
- Update dependencies

* Mon Jul 15 2013 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Compile test updated, to hopefully fix mswin32 parsing issues

* Wed Jul 10 2013 Paul Howarth <paul@city-fan.org> - 0.007-1
- Update to 0.007
  - Fix subtest tests to work on Test::More before 0.95_01 (CPAN RT#86802)
- BR: perl(Capture::Tiny)
- Bump perl(Module::Build::Tiny) version requirement to 0.024
- Bump perl(Test::CheckDeps) version requirement to 0.006
- Drop perl(Test::More) version requirement to 0.94

* Tue Jul  9 2013 Paul Howarth <paul@city-fan.org> - 0.006-1
- Initial RPM version
